---
categories: databases
title: Howto MySQL : mariabackup.
...

## Vue d'ensemble

Mariabackup est un outil qui permet de faire un backup physique d'une instance mysql / mariadb avec les moteurs InnoDB / Aria et MyISAM.
Pour InnoDB un backup "à chaud" est possible, qui a originellement été introduit dans Percona XtraBackup 2.3.8

MariaDB 10.1 a introduit des fonctionnalités exclusives à MariaDB telles que la compression des pages (InnoDB Page Compression) et le chiffrement des données (Data-at-Rest Encryption), ces fonctionnalités exclusives ne sont pas prise en charge par des autres solutions de backup, telles que Percona XtraBackup.

Mariabackup supporte toutes les fonctionnalités de Percona XtraBackup, et celles exclusives a MariaDB telles que :

* Sauvegarde et restauration des tables utilisant **Data-at-Rest Encryption**.
* Sauvegarde et restauration des tables utilisant **InnoDB Page Compression**.
* **mariabackup SST method** avec un cluster Galera.
* Sauvegarde et restauration des tables utilisant **MyRocks** comme moteur de stockage à partir de MariaDB 10.2.16 and MariaDB 10.3.8

## Différences avec Percona XtraBackup

* Percona XtraBackup copie ses fichiers de journalisation InnoDB dans le fichier xtrabackup_logfile, tandis que Mariabackup utilise le fichier ib_logfile0.
* Il n'y a pas de lien symbolique entre mariabackup et innobackupex, comme pour xtrabackup. À la place, mariabackup a l'option de ligne de commande --innobackupex pour activer les options compatibles avec innobackupex.
* Les options _--compact_ et _--rebuild_indexes_ de XtraBackup ne sont pas supportées.
* L'utilitaire _xbstream_ de XtraBackup a été renommé _mbstream._ Cependant, pour sélectionner ce format de sortie lors de la création d'une sauvegarde, l'option _--stream_ de Mariabackup attend toujours la valeur xbstream.
* Mariabackup ne supporte pas l'option _lockless binlog_ d'XtraBackup.

## Installer Mariabackup

L’exécutable mariabackup est inclus dans le paquet _mariadb-client_ sur Debian 9.

~~~
# apt install mariadb-client
~~~

Sur Debian 10 mariabackup est présent dans le paquet _mariadb-backup_ :

~~~
# apt install mariadb-backup
~~~

Un utilisateur spécifique a Mariabackup doit être créer, avec les droits RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT :

~~~
MariaDB > GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO 'mariabackup'@'localhost' IDENTIFIED BY 'foobarcorp';
~~~

Les informations du compte _mariabackup_ peuvent être spécifié dans un groupe d'option client dans le fichier _.my.cnf_ comme ceci :

~~~
[mariabackup]
user=mariabackup
password=foobarcorp
~~~

## Sauvegarde complète (Full Backup)

Afin de sauvegarder la base de données, vous devez exécuter Mariabackup avec l'option --backup pour lui indiquer d'effectuer une sauvegarde et avec l'option --target-dir pour lui indiquer où placer les fichiers de sauvegarde. 
Lors d'une sauvegarde complète, le répertoire cible doit être vide ou ne pas exister.

Pour créer un backup, exécuter la commande suivante :

~~~
# mariabackup --backup --target-dir=/home/mariabackup/ --user=mariabackup --password=foobarcorp
~~~
_Note : Les options --user et --password n'ont pas besoin d'être précisé si on les gères dans le .my.cnf_ 

La durée de la sauvegarde dépend de la taille des bases de données ou des tables que vous sauvegardez. Vous pouvez annuler la sauvegarde si nécessaire, car le processus de sauvegarde ne modifie pas la base de données.

## Restauration complète

### Préparation du backup

Les fichiers de données créés par Mariabackup dans le répertoire cible ne sont pas cohérents à un point dans le temps, étant donné que les fichiers de données sont copiés à différents moments de la sauvegarde.

Si vous essayez de restaurer à partir de ces fichiers, InnoDB remarque les incohérences et va planté pour protéger les bases de données contre la corruption.

Avant de pouvoir restaurer à partir d'une sauvegarde, vous devez d'abord la préparer pour rendre les fichiers de données cohérents. Vous pouvez le faire avec l'option _--prepare_ :

~~~
# mariabackup --prepare --target-dir=/home/mariabackup/
~~~

### Restauration du backup

Une fois la préparation de la sauvegarde terminée, vous pouvez la restaurer en utilisant les options _--copy-back_ ou _--move-back_.

L'option _--move-back_ déplace les fichiers de sauvegarde vers le datadir, ainsi les fichiers de la sauvegarde d'origine sont perdus.

Voici la provédure pour restauré un backup :

* Tout d’abord, arrêtez le processus MariaDB Server.
* Ensuite, assurez-vous que le datadir soit vide.
* Ensuite, lancez Mariabackup avec l’une des options mentionnées ci-dessus:

~~~
# mariabackup --copy-back --target-dir=/home/mariabackup/
~~~
* Ensuite, vous devrez peut-être corriger les droits des fichiers :

~~~
# chown -R mysql:mysql /var/lib/mysql/
~~~

Lorsque Mariabackup restaure une base de données, il conserve les privilèges de fichier et de répertoire de la sauvegarde. 
Cependant, il écrit les fichiers sur le disque en tant qu'utilisateur et groupe restaurant la base de données.

En tant que tel, après la restauration d'une sauvegarde, vous devrez peut-être ajuster le propriétaire du répertoire de données pour qu'il corresponde à l'utilisateur et au groupe du serveur MariaDB, généralement mysql pour les deux.

## Sauvegarde incrémentielle avec Mariabackup

Lorsque vous utilisez Mariabackup, vous avez la possibilité d'effectuer une sauvegarde complète ou incrémentielle.
Les sauvegardes complètes créent une copie complète dans un répertoire vide tandis que les sauvegardes incrémentielles mettent à jour une sauvegarde précédente avec de nouvelles données.

Les pages InnoDB contiennent des numéros de séquence de journal, ou LSN. Chaque fois que vous modifiez une ligne sur une table InnoDB de la base de données, le moteur de stockage incrémente ce nombre. 

Lors de l'exécution d'une sauvegarde incrémentielle, Mariabackup vérifie la sauvegarde la plus récente du LSN par rapport aux LSN contenus dans la base de données.
Il met ensuite à jour tous les fichiers de sauvegarde en retard.

### Mise en place de la sauvegarde incrémentielle

Pour effectuer une sauvegarde incrémentielle, vous devez d’abord effectuer une sauvegarde complète, comme vu précédemment :

~~~
# mariabackup --backup --target-dir=/home/mariabackup/
~~~

Ceci sauvegarde toutes les bases de données dans le répertoire cible /home/mariabackup/
Si vous regardez dans ce répertoire dans le fichier _xtrabackup_checkpoints_, vous pouvez voir les données de LSN fournies par InnoDB :

~~~
# cat /home/mariabackup/xtrabackup_checkpoints

backup_type = full-prepared
from_lsn = 0
to_lsn = 6902092065
last_lsn = 6902092065
recover_binlog_info = 0
~~~

Une fois que vous avez créé une sauvegarde complète sur votre système, vous pouvez également sauvegarder les modifications incrémentielles aussi souvent que vous le souhaitez.

Pour effectuer une sauvegarde incrémentielle, vous devez exécuter Mariabackup avec l'option _--backup_ pour lui indiquer d'effectuer une sauvegarde et avec l'option _--target-dir_ pour lui indiquer où placer les modifications incrémentielles. 

Le répertoire cible doit être vide. Vous devez également l'exécuter avec l'option _--incremental-basedir_ pour lui indiquer le chemin d'accès à la sauvegarde complète effectuée ci-dessus :

~~~
mariabackup --backup --target-dir=/home/mariabackup/inc1/ --incremental-basedir=/home/mariabackup/
~~~

Cette commande crée une série de fichiers delta qui stockent les modifications incrémentielles dans _/home/mariabackup/inc1/_
Vous pouvez trouver un fichier _xtrabackup_checkpoints_ similaire dans ce répertoire, avec les valeurs LSN mises à jour :

~~~
# cat /home/mariabackup/inc1/xtrabackup_checkpoints 

backup_type = incremental
from_lsn = 6902092065
to_lsn = 6909766286
last_lsn = 6909766286
recover_binlog_info = 0
~~~

Pour effectuer des sauvegardes incrémentielles supplémentaires, vous pouvez ensuite utiliser le répertoire de base incrémentiel de la sauvegarde incrémentielle précédente comme répertoire cible pour la prochaine sauvegarde incrémentielle :

~~~
# mariabackup --backup --target-dir=/home/mariabackup/inc2/ --incremental-basedir=/home/mariabackup/inc1/
~~~

### Restauration d'un sauvegarde incrémentielle

En suivant les étapes ci-dessus, vous avez trois sauvegardes dans /home/mariabackup/ : la première est une sauvegarde complète, les autres sont incrémentées sur cette première sauvegarde.

Pour restaurer une sauvegarde dans la base de données, vous devez d’abord appliquer les sauvegardes incrémentielles à la sauvegarde complète de base.
Ceci est fait en utilisant l'option de commande _--prepare_ avec l'option _--apply-log-only_.

Premièrement, nous préparons le backup de base :

~~~
# mariabackup --prepare --apply-log-only --target-dir=/home/mariabackup/
~~~

Ensuite, appliquez les modifications incrémentielles à la sauvegarde complète de base :

~~~
# mariabackup --prepare --apply-log-only --target-dir=/home/mariabackup/ --incremental-dir=/home/mariabackup/inc1/
~~~

L'exécution de cette commande met la sauvegarde complète de base, c'est-à-dire _/home/mariabackup/_, en synchronisation avec les modifications contenues dans la première sauvegarde incrémentielle.
Répétez l'étape ci-dessus pour appliquer les modifications de la sauvegarde _/home/mariabackup/inc2/_ à la base :

~~~
# mariabackup --prepare --apply-log-only --target-dir=/home/mariabackup/ --incremental-dir=/home/mariabackup/inc2/
~~~

### Restauration du backup incrémentiel 

Nous pouvons désormais restaurer le backup de la même manière que cité plus haut :

* Arrêtez le processus MariaDB Server, assurez-vous que le datadir soit vide, lancez Mariabackup comme ceci :

~~~
# mariabackup --copy-back --target-dir=/home/mariabackup/
~~~

Assurez-vous que les droit de _/var/lib/mysql/ soit correct.

